@@ -1,7 +1,7 @@
 use crate::types::RancherLinks;
 use std::collections::HashMap;
 
-#[derive(serde::Deserialize)]
+#[derive(Debug, serde::Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct Collection<T> {
     #[serde(rename = "type")]
